/* Copyright (C) 2009, 2010, 2011 Keith Crane

This file is part DFILE Tools.

DFILE Tools is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or (at
your option) any later version.

DFILE Tools is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with DFILE Tools; see the file COPYING.  If not, see
<http://www.gnu.org/licenses/>. */

#include <stdio.h>
#include "tbox.h"

/*
** This is a wrapper function for fmt_ctime().
*/
const char *get_ctime( void )
{
	static const char	time_unknown[] = "TIME UNKNOWN";
	const char	*ptr;

	ptr = fmt_ctime();
	if ( ptr == (const char *)0 ) {
		ptr = time_unknown;
	}

	return ptr;
}
